@@ -1,16 +1,13 @@
-import cctk
 import stjames
 import time
 from typing import Optional
-
-from .utils import cctk_to_stjames, smiles_to_stjames
 from .workflow import Workflow
 
 """ A high-level interface to submitting a calculation. """
 
 
 def compute(
-    molecule: str | cctk.Molecule | stjames.Molecule,
+    molecule: str | stjames.Molecule,
     workflow_type: str,
     name: str = "",
     folder_uuid: Optional[stjames.UUID] = None,
@@ -21,9 +18,7 @@ def compute(
     """High-level function to compute and return workflows."""
 
     if isinstance(molecule, str):
-        stjmol = smiles_to_stjames(molecule)
-    elif isinstance(molecule, cctk.Molecule):
-        stjmol = cctk_to_stjames(molecule)
+        stjmol = stjames.Molecule.from_smiles(molecule) 
     elif isinstance(molecule, stjames.Molecule):
         stjmol = molecule
     else:
